import { Injectable } from '@angular/core';
import { HttpClient, HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';

import { SERVER_API_URL } from 'app/app.constants';
import { createRequestOption } from 'app/shared/util/request-util';
import { IGitFilesPageDetails } from 'app/shared/model/git-files-page-details.model';
import { IGitFilesAggregation } from 'app/shared/model/git-files-aggregation';
import { SearchInput } from 'app/shared/model/search-input.model';

type EntityResponseTypePageDetails = HttpResponse<IGitFilesPageDetails>;
type EntityResponseTypeAggregation = HttpResponse<IGitFilesAggregation>;

@Injectable({ providedIn: 'root' })
export class SearchResultService {
  public resourceSearchUrlPageDetails = SERVER_API_URL + 'api/_search/git-files/page-details';
  public resourceSearchUrlAggregation = SERVER_API_URL + 'api/_search/git-files/aggregation';

  constructor(protected http: HttpClient) {}

  //
  // find(id: number): Observable<EntityResponseType> {
  //   return this.http
  //     .get<ISearchResult>(`${this.resourceUrl}/${id}`, {observe: 'response'})
  //     .pipe();
  // }
  //
  // query(req?: any): Observable<EntityResponseType> {
  //   const options = createRequestOption(req);
  //   return this.http
  //     .get<ISearchResult>(this.resourceUrl, {params: options, observe: 'response'})
  //     .pipe();
  // }
  //
  // delete(id: number): Observable<HttpResponse<{}>> {
  //   return this.http.delete(`${this.resourceUrl}/${id}`, {observe: 'response'});
  // }

  searchPageDetails(searchInput: SearchInput, page: number): Observable<EntityResponseTypePageDetails> {
    const req = {
      fulltextQuery: searchInput.fulltextQuery,
      metadataProgrammingLanguage: searchInput.metadata.programmingLanguage,
      metadataKeywords: searchInput.metadata.keyword,
      metadataNaturalLanguage: searchInput.metadata.naturalLanguage,
      metadataLicense: searchInput.metadata.license,
      metadataAuthor: searchInput.metadata.author,
      selectedRepository: searchInput.fulltextSelection.repository.map(value => value.key),
      selectedUniversity: searchInput.fulltextSelection.university.map(value => value.key),
      selectedFileFormat: searchInput.fulltextSelection.fileFormat.map(value => value.key),
      page: searchInput.page,
      pageSize: page,
    };
    const options = createRequestOption(req);
    return this.http
      .get<IGitFilesPageDetails>(this.resourceSearchUrlPageDetails, { params: options, observe: 'response' })
      .pipe();
  }

  searchAggregation(req: { query: string }): Observable<EntityResponseTypeAggregation> {
    const options = createRequestOption(req);
    return this.http
      .get<IGitFilesAggregation>(this.resourceSearchUrlAggregation, { params: options, observe: 'response' })
      .pipe();
  }

  /*
  protected convertDateFromClient(searchResult: ISearchResult): ISearchResult {
    const copy: ISearchResult = Object.assign({}, searchResult, {
      lastModified: searchResult.lastModified && searchResult.lastModified.isValid() ? searchResult.lastModified.toJSON() : undefined,
      lastAccessed: searchResult.lastAccessed && searchResult.lastAccessed.isValid() ? searchResult.lastAccessed.toJSON() : undefined,
      indexingDate: searchResult.indexingDate && searchResult.indexingDate.isValid() ? searchResult.indexingDate.toJSON() : undefined,
    });
    return copy;
  }

  protected convertDateFromServer(res: EntityResponseType): EntityResponseType {
    if (res.body) {
      res.body.lastModified = res.body.lastModified ? moment(res.body.lastModified) : undefined;
      res.body.lastAccessed = res.body.lastAccessed ? moment(res.body.lastAccessed) : undefined;
      res.body.indexingDate = res.body.indexingDate ? moment(res.body.indexingDate) : undefined;
    }
    return res;
  }

  protected convertDateArrayFromServer(res: EntityArrayResponseType): EntityArrayResponseType {
    if (res.body) {
      res.body.forEach((searchResult: ISearchResult) => {
        searchResult.lastModified = searchResult.lastModified ? moment(searchResult.lastModified) : undefined;
        searchResult.lastAccessed = searchResult.lastAccessed ? moment(searchResult.lastAccessed) : undefined;
        searchResult.indexingDate = searchResult.indexingDate ? moment(searchResult.indexingDate) : undefined;
      });
    }
    return res;
  }
  */
}
